@@ -1,6 +1,6 @@
 package Search::Sitemap::Index;
 use strict; use warnings;
-our $VERSION = '2.10';
+our $VERSION = '2.13';
 our $AUTHORITY = 'cpan:JASONK';
 use Moose;
 extends 'Search::Sitemap';
@@ -26,18 +26,21 @@ __END__
 
 =head1 NAME
 
-Search::SiteMap::Index - Perl extension for managing SiteMap Indexes
+Search::Sitemap::Index - Perl extension for managing Sitemap Indexes
 
 =head1 SYNOPSIS
 
-  use Search:SiteMap::Index;
+  use Search::Sitemap::Index;
   
-  my $index = Search::SiteMap::Index->new( file => 'sitemap-index.gz' );
+  my $index = Search::Sitemap::Index->new();
+  $index->read( 'sitemap-index.gz' );
   
-  $index->add( Search::SiteMap::URL->new(
+  $index->add( Search::Sitemap::URL->new(
     loc     => 'http://www.jasonkohles.com/sitemap1.gz',
     lastmod => '2005-11-01',
   ) );
+
+  $index->write( 'sitemap-index.gz' );
   
 =head1 DESCRIPTION
 
